@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder class
 package PONAPI::Builder::Document;
 
 use Moose;
@@ -40,14 +40,14 @@ has req_path => (
     default => sub { '/' },
 );
 
-has 'is_collection' => (
+has is_collection => (
     is      => 'ro',
     writer  => '_set_is_collection',
     isa     => 'Bool',
     default => 0
 );
 
-has '_included' => (
+has _included => (
     init_arg => undef,
     traits   => [ 'Array' ],
     is       => 'ro',
@@ -61,14 +61,14 @@ has '_included' => (
     }
 );
 
-has '_resource_builders' => (
+has _resource_builders => (
     init_arg  => undef,
     traits    => [ 'Array' ],
     is        => 'ro',
     isa       => 'ArrayRef[ PONAPI::Builder::Resource | PONAPI::Builder::Resource::Null ]',
     lazy      => 1,
     default   => sub { +[] },
-    predicate => '_has_resource_builders',
+    predicate => 'has_resource_builders',
     handles   => {
         '_num_resource_builders' => 'count',
         # private ...
@@ -77,7 +77,7 @@ has '_resource_builders' => (
     }
 );
 
-has 'errors_builder' => (
+has errors_builder => (
     init_arg  => undef,
     is        => 'ro',
     isa       => 'PONAPI::Builder::Errors',
@@ -102,12 +102,12 @@ sub has_errors {
 
 sub has_resource {
     my $self = $_[0];
-    $self->_has_resource_builders && $self->_num_resource_builders > 0;
+    $self->has_resource_builders && $self->_num_resource_builders > 0;
 }
 
 sub has_resources {
     my $self = $_[0];
-    $self->_has_resource_builders && $self->_num_resource_builders > 1;
+    $self->has_resource_builders && $self->_num_resource_builders > 1;
 }
 
 sub add_resource {
@@ -151,7 +151,7 @@ sub build {
         $result->{meta}  = $self->_meta                if $self->has_meta;
         $result->{links} = $self->links_builder->build if $self->has_links_builder;
 
-        if ( $self->_has_resource_builders ) {
+        if ( $self->has_resource_builders ) {
             if ( $self->is_collection ) {
                 # if it is a collection, then
                 # call build on each one ...
@@ -215,19 +215,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder::Document - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder::Document - document builder class
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
