@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder - links
 package PONAPI::Builder::Links;
 
 use Moose;
@@ -6,7 +6,7 @@ use Moose;
 with 'PONAPI::Builder',
      'PONAPI::Builder::Role::HasMeta';
 
-has '_links' => (
+has _links => (
     init_arg => undef,
     traits   => [ 'Hash' ],
     is       => 'ro',
@@ -24,15 +24,13 @@ has '_links' => (
 );
 
 sub add_link {
-    my $self = $_[0];
-    my $rel  = $_[1];
-    my $url  = $_[2];
+    my ( $self, $rel, $url ) = @_;
     $self->_add_link( $rel => $url );
     return $self;
 }
 
 sub add_links {
-    my ($self, %links) = @_;
+    my ( $self, %links ) = @_;
     $self->add_link( $_, $links{ $_ } ) foreach keys %links;
     return $self;
 }
@@ -61,19 +59,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder::Links - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder::Links - document builder - links
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
