@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: Data Abstraction Object class
 package PONAPI::DAO;
 
 use Moose;
@@ -16,7 +16,7 @@ use PONAPI::DAO::Request::DeleteRelationships;
 
 has repository => (
     is       => 'ro',
-    does     => 'PONAPI::DAO::Repository',
+    does     => 'PONAPI::Repository',
     required => 1,
 );
 
@@ -56,10 +56,11 @@ sub _action {
     my @ret;
     eval {
         @ret = $action_class->new($ponapi_parameters)->execute();
+        1;
     } or do {
         my $e = $@ || 'Unknown error';
-        @ret = PONAPI::DAO::Exception
-                    ->new_from_exception($e, $self)
+        @ret = PONAPI::Exception
+                    ->new_from_exception($e)
                     ->as_response;
     };
 
@@ -77,11 +78,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO - Data Abstraction Object class
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -170,7 +171,7 @@ version 0.001002
 =head1 DESCRIPTION
 
 Data Access Object for the JSON API.  This sits in between a server
-and a L<repository|"PONAPI::DAO::Repository">.
+and a L<repository|"PONAPI::Repository">.
 
 All public DAO methods will return a 3-item list of a status, headers,
 and the response body; this can then be fed directly to a PSGI application:
@@ -181,10 +182,6 @@ plain hashrefs, and they B<must> include both a C<type> and C<id>; they
 may also contain additional keys.  See L<http://jsonapi.org/format/#document-resource-objects>
 for a more in-depth description.
 
-=head1 NAME
-
-PONAPI::DAO - Interface to a JSON API.
-
 =head1 METHODS
 
 =head2 new
@@ -195,7 +192,7 @@ Create a new instance of PONAPI::DAO.
         repository => $repository,
     );
 
-Where C<$repository> implements the L<PONAPI::DAO::Repository> role.
+Where C<$repository> implements the L<PONAPI::Repository> role.
 
 As expanded below in L</"Return value of update operations">, the JSON API specification requires some
 update operations returning C<200 OK> to also do a C<retrieve> and include
@@ -554,13 +551,27 @@ Adds a new member to the specified one-to-many relationship.
 
 See also L</"Return value of update operations">.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
