@@ -1,11 +1,11 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request - create
 package PONAPI::DAO::Request::Create;
 
 use Moose;
 
 extends 'PONAPI::DAO::Request';
 
-with 'PONAPI::DAO::Request::Role::HasDataAttribute',
+with 'PONAPI::DAO::Request::Role::HasData',
      'PONAPI::DAO::Request::Role::HasDataMethods';
 
 sub execute {
@@ -45,19 +45,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::Create - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::Create - DAO request - create
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
