@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request - create relationships
 package PONAPI::DAO::Request::CreateRelationships;
 
 use Moose;
@@ -6,16 +6,11 @@ use Moose;
 extends 'PONAPI::DAO::Request';
 
 with 'PONAPI::DAO::Request::Role::UpdateLike',
+     'PONAPI::DAO::Request::Role::HasDataBulk',
      'PONAPI::DAO::Request::Role::HasDataMethods',
      'PONAPI::DAO::Request::Role::HasID',
      'PONAPI::DAO::Request::Role::HasRelationshipType';
 
-has data => (
-    is        => 'ro',
-    isa       => 'ArrayRef[HashRef]',
-    predicate => 'has_data',
-);
-
 sub check_data_type_match { 1 } # to avoid code duplications in HasDataMethods
 
 sub execute {
@@ -54,19 +49,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::CreateRelationships - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::CreateRelationships - DAO request - create relationships
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
