@@ -1,17 +1,17 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request role - `update` & like related functionality
 package PONAPI::DAO::Request::Role::UpdateLike;
 
 use Moose::Role;
 
-use PONAPI::DAO::Constants;
-use PONAPI::DAO::Exception;
+use PONAPI::Constants;
+use PONAPI::Exception;
 
-has 'respond_to_updates_with_200' => (
+has respond_to_updates_with_200 => (
     is  => 'ro',
     isa => 'Bool',
 );
 
-has 'update_nothing_status' => (
+has update_nothing_status => (
     is      => 'ro',
     isa     => 'Int',
     # http://jsonapi.org/format/#crud-updating-relationship-responses-204
@@ -24,7 +24,7 @@ has 'update_nothing_status' => (
 sub _verify_update_response {
     my ( $self, $ret, @extra ) = @_;
 
-    PONAPI::DAO::Exception->throw(
+    PONAPI::Exception->throw(
         internal => 1,
         message  => "update-like operation returned an unexpected value"
     ) unless exists $PONAPI_UPDATE_RETURN_VALUES{$ret};
@@ -57,6 +57,10 @@ sub _add_success_meta {
     if ( $return_status == PONAPI_UPDATED_NOTHING ) {
         my $status = $self->update_nothing_status;
         $self->document->set_status($status);
+        # This should NEVER show up in a response, because it would
+        # mean a 204 with a body; I'm still leaving it here because
+        # a 204+body is preferable to a server error due to an empty
+        # document.
         $detail = "modified nothing for $resource"
     }
 
@@ -72,7 +76,7 @@ sub _get_resource_for_meta {
     return $link . " => " . $self->json->encode( $self->data );
 }
 
-no PONAPI::DAO::Constants;
+no PONAPI::Constants;
 no Moose::Role; 1;
 
 __END__
@@ -83,19 +87,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::Role::UpdateLike - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::Role::UpdateLike - DAO request role - `update` & like related functionality
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
