@@ -1,11 +1,10 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: mock repository class
 package Test::PONAPI::DAO::Repository::MockDB;
 
 use Moose;
 
 use DBI;
 use SQL::Composer;
-use Scalar::Util qw/looks_like_number/;
 
 # We MUST use DBD::SQLite before ::Constants to get anything useful!
 use DBD::SQLite;
@@ -17,10 +16,10 @@ use Test::PONAPI::DAO::Repository::MockDB::Table::Articles;
 use Test::PONAPI::DAO::Repository::MockDB::Table::People;
 use Test::PONAPI::DAO::Repository::MockDB::Table::Comments;
 
-use PONAPI::DAO::Constants;
-use PONAPI::DAO::Exception;
+use PONAPI::Constants;
+use PONAPI::Exception;
 
-with 'PONAPI::DAO::Repository';
+with 'PONAPI::Repository';
 
 has dbh => (
     is     => 'ro',
@@ -108,8 +107,7 @@ sub retrieve_relationships {
 
     my $sort = $args{sort} || [];
     if ( @$sort ) {
-        # TODO move to the request:
-        PONAPI::DAO::Exception->throw(
+        PONAPI::Exception->throw(
             message => "You can only sort by id in retrieve_relationships"
         ) if @$sort > 1 || $sort->[0] !~ /\A(-)?id\z/;
 
@@ -117,8 +115,7 @@ sub retrieve_relationships {
 
         my $table_obj    = $self->tables->{$type};
         my $relation_obj = $table_obj->RELATIONS->{$rel_type};
-
-        my $id_column     = $relation_obj->REL_ID_COLUMN;
+        my $id_column    = $relation_obj->REL_ID_COLUMN;
 
         @$sort = ($desc ? '-' : '') . $id_column;
     }
@@ -259,7 +256,7 @@ sub _create_relationships {
         my $data_type = delete $relationship->{type};
 
         if ( $data_type ne $key_type ) {
-            PONAPI::DAO::Exception->throw(
+            PONAPI::Exception->throw(
                 message          => "Data has type `$data_type`, but we were expecting `$key_type`",
                 bad_request_data => 1,
             );
@@ -328,7 +325,6 @@ sub create_relationships {
 
     $dbh->commit;
     return $ret;
-    # TODO: add missing login
 }
 
 sub update {
@@ -357,8 +353,6 @@ sub update {
 sub _update {
     my ( $self, %args ) = @_;
     my ( $type, $id, $data ) = @args{qw< type id data >};
-
-    # TODO this needs to be part of $data's validation in Request.pm
     my ($attributes, $relationships) = map $_||{}, @{ $data }{qw/ attributes relationships /};
 
     my $return = PONAPI_UPDATED_NORMAL;
@@ -465,7 +459,6 @@ sub update_relationships {
     $dbh->commit;
 
     return $ret;
-    # TODO: add missing login
 }
 
 sub delete : method {
@@ -480,8 +473,6 @@ sub delete : method {
 
     my $sth = $self->_db_execute( $stmt );
 
-    # TODO: Should this also clear relationships?
-
     return;
 }
 
@@ -527,7 +518,7 @@ sub _delete_relationships {
         my $data_type = $resource->{type};
 
         if ( $data_type ne $key_type ) {
-            PONAPI::DAO::Exception->throw(
+            PONAPI::Exception->throw(
                 message          => "Data has type `$data_type`, but we were expecting `$key_type`",
                 bad_request_data => 1,
             );
@@ -557,7 +548,6 @@ sub _delete_relationships {
 
     $ret = PONAPI_UPDATED_NOTHING if !$rows_modified;
 
-    # TODO: add missing login
     return $ret;
 }
 
@@ -622,13 +612,13 @@ sub _validate_page {
     my ($self, $page) = @_;
 
     exists $page->{limit}
-        or PONAPI::DAO::Exception->throw(message => "Limit missing for `page`");
+        or PONAPI::Exception->throw(message => "Limit missing for `page`");
 
-    looks_like_number($page->{limit})
-        or PONAPI::DAO::Exception->throw(message => "Bad limit value ($page->{limit}) in `page`");
+    $page->{limit} =~ /\A[0-9]+\z/
+        or PONAPI::Exception->throw(message => "Bad limit value ($page->{limit}) in `page`");
 
-    !exists $page->{offset} || looks_like_number($page->{offset})
-        or PONAPI::DAO::Exception->throw(message => "Bad offset value in `page`");
+    !exists $page->{offset} || ($page->{offset} =~ /\A[0-9]+\z/)
+        or PONAPI::Exception->throw(message => "Bad offset value in `page`");
 
     $page->{offset} ||= 0;
 
@@ -644,8 +634,6 @@ sub _add_resource_relationships {
 
     # Do not add sort or page here -- those were for the primary resource
     # *only*.
-    # TODO any way to make them happen here? Fetching a resource with a million
-    # relationships seems bad.
     my $rels = $self->_fetchall_relationships(
         type     => $type,
         id       => $rec->id,
@@ -687,8 +675,6 @@ sub _add_included {
     $filter->{id} = $ids;
 
     # Do NOT add sort -- sort here was for the *main* resource!
-    # TODO spec is vague regarding page here.  How do you paginate included
-    # resources?
     my $stmt = $self->tables->{$type}->select_stmt(
         type   => $type,
         filter => $filter,
@@ -789,21 +775,20 @@ sub _db_execute {
 
         my $message;
         if ( $sqlite_constraint_failed && $err_id && $err_id == $sqlite_constraint_failed ) {
-            PONAPI::DAO::Exception->throw(
+            PONAPI::Exception->throw(
                 message   => "Table constraint failed: $errstr",
                 sql_error => 1,
                 status    => 409,
             );
         }
-        # TODO better error messages for other codes
         elsif ( $err_id ) {
-            PONAPI::DAO::Exception->throw(
+            PONAPI::Exception->throw(
                 message   => $errstr,
                 sql_error => 1,
             );
         }
         else {
-            PONAPI::DAO::Exception->throw(
+            PONAPI::Exception->throw(
                 message => "Non-SQL error while running query? $e"
             )
         }
@@ -823,19 +808,33 @@ __END__
 
 =head1 NAME
 
-Test::PONAPI::DAO::Repository::MockDB - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+Test::PONAPI::DAO::Repository::MockDB - mock repository class
 
 =head1 VERSION
 
-version 0.001002
+version 0.002000
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
